def getPercent(x, baseValue):
    """
    Calculate percentage.
    
    Returns
    -------
    float
        Percentage of `x` out of `baseValue`, normalised to 100.
    """
    return x/baseValue*100

def getPercentString(x, baseValue):
    """
    Calculate percentage and return as string.
    
    Returns
    -------
    str
        String of result of :func:`getPercent`.
    """
    return str( getPercent(x, baseValue) )

def getPercentStringShort(x, baseValue, decimalPlaces = 1):
    """
    Calculate percentage and return as shortened string.
    
    Parameters
    ----------
    decimalPlaces : int
        The number of decimal places to the right to conserve.
    
    Returns
    -------
    str
        String of result of :func:`getPercent`, shortened to `decimalPlaces` decimal places.
    """
    return ("%2." + str( decimalPlaces ) + "f") % getPercent(x, baseValue)

def getPercentSentence(x, baseValue, decimalPlaces = 1):
    """
    Calculate percentage and return shortened string within a fancy sentence.
    
    Parameters
    ----------
    decimalPlaces : int
        The number of decimal places to the right to conserve.
    
    Returns
    -------
    str
        String of result of :func:`getPercent`, shortened to `decimalPlaces` decimal places, and put into a complete sentence of the form "`x`/`baseValue` -> result%"", i.e. ``23/42 -> 54.76%``.
    """
    return str(x) + "/" + str(baseValue) + " -> " + getPercentStringShort(x, baseValue, decimalPlaces) + '%'